@@ -91,8 +91,6 @@ class Op:
             else:
                 if not isinstance(type_, str) and hasattr(type_, '__name__'):
                     type_ = type_.__name__
-                else:
-                    type_ = 'any'
             info = {
                 'name': param,
                 'type': type_,
